Learn R Programming

LifeInsuranceContracts (version 0.0.4)

costsDisplayTable: Helper function to display all cost definitions in a concise table

Description

Returns a data.frame with columns

Usage

costsDisplayTable(costs)

Arguments

costs

The cost structure to be displayed in a concise table style.