fillFields: Overwrite all existing fields with default values given
Description
Overwrite all existing fields in the first argument with
values given in valuelist. Members of valuelist that are not yet in
fields are ignored. This allows a huge valuelist to be used to fill
fields in multiple lists with given structure.
Usage
fillFields(fields, valuelist)
Arguments
- fields
existing list
- valuelist
list of fields to replace in fields. Only keys that exist in fields are overwritten, no new fields are added to fields