Learn R Programming

LifeInsuranceContracts (version 0.0.4)

head0: Set all entries of the given vector to 0 up until index 'start'

Description

Set all entries of the given vector to 0 up until index 'start'

Usage

head0(v, start = 0)

Value

the vector v with the first start elements replaced by 0.

Arguments

v

the vector to modify

start

how many leading elements to zero out

Examples

Run this code
head0(1:10, 3)

Run the code above in your browser using DataLab