powered by
hook
val
If hook is a function, apply it to val, otherwise return val unchanged
applyHook(hook, val, ...)
(optional) function to apply to val and the other parameters
The value to which the hook is applied (ifgiven)
optional parameters passed to the hook function (if it is a function)
# NOT RUN { applyHook(NULL, 3) # returns 3 unchanged applyHook(function(x) 2*x, 3) # applies the function, returns 6 applyHook(`+`, 3, 1) # returns 4 # }
Run the code above in your browser using DataLab