powered by
Set all entries of the given vector to 0 up until index 'start'
head0(v, start = 0)
the vector v with the first start elements replaced by 0.
v
start
the vector to modify
how many leading elements to zero out
head0(1:10, 3)
Run the code above in your browser using DataLab