powered by
Set all entries of the given vector to 0 up until index 'start'
head0(v, start = 0)
the vector to modify
how many leading elements to zero out
the vector v with the first start elements replaced by 0.
v
start
# NOT RUN { head0(1:10, 3) # }
Run the code above in your browser using DataLab