powered by
val
If val is a function, evaluate it, otherwise return val
valueOrFunction(val, ...)
Function or value
Argument passed to val if it is a function
# NOT RUN { valueOrFunction(3) # returns 3 valueOrFunction(`+`, 1, 2) # also returns 3 A = `+` valueOrFunction(A, 1, 2) # }
Run the code above in your browser using DataLab